@@ -76,7 +76,7 @@ svn update --quiet subdirs teamnames scripts
 mkdir -p "${PO_DIR}"
 
 # check out all missing directories and files (recursively)
-if test -z ${LINGUAS} ; then
+if test -z "${LINGUAS}" ; then
     LINGUAS=`cat subdirs | grep -v x-test`
 fi
 FOUND_LINGUAS=""
@@ -87,7 +87,19 @@ touch ${LANG_NAMES_FILE}
 
 for lang in ${LINGUAS}; do
 
-    lang_team=`cat teamnames | grep ^${lang}=`
+    if test ! -e ${lang} ; then
+	checkout "" "${lang}"
+    fi
+
+    # skip languages which have no files (like "en")
+    if test ! -e ${lang} ; then
+        continue
+    fi
+
+    lang_team=`cat teamnames | grep ^${lang}=` || true
+    if test -z "${lang_team}" ; then
+	lang_team="${lang}"
+    fi
 
     echo -n "processing ${lang} - `echo ${lang_team} | cut -d = -f 2`... "
 
@@ -173,6 +185,7 @@ for lang in ${FOUND_HANDBOOKS}; do
 	if test "${lang}/docs/${CATEGORY}/kwave/index.docbook" -ot \
 	         "${lang}/docmessages/${CATEGORY}/kwave.po" ; then
 	    echo -n "${lang}: index.docbook is out of date - updating... "
+	    checkout "" "${lang}/docmessages/language"
 	    scripts/update_xml ${lang} ${CATEGORY} kwave > /dev/null
 	    echo "done"
 	fi
