@@ -22,7 +22,6 @@
 
 #include <errno.h>
 #include <math.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 
@@ -125,7 +124,7 @@ Kwave::TopWidget::TopWidget(Kwave::App &app)
     Q_ASSERT(status_bar);
     if (!status_bar) return;
 
-    QLabel *spacer = new QLabel(this);
+    QLabel *spacer = new(std::nothrow) QLabel(this);
     const int frame_style = QFrame::StyledPanel | QFrame::Sunken;
     status_bar->addWidget(spacer);
     spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
@@ -135,17 +134,17 @@ Kwave::TopWidget::TopWidget(Kwave::App &app)
     spacer->setSizePolicy(policy);
     policy.setHorizontalStretch(0);
 
-    m_lbl_status_cursor = new QLabel(this);
+    m_lbl_status_cursor = new(std::nothrow) QLabel(this);
     status_bar->addWidget(m_lbl_status_cursor);
     m_lbl_status_cursor->setSizePolicy(policy);
     m_lbl_status_cursor->setFrameStyle(frame_style);
 
-    m_lbl_status_mode = new QLabel(this);
+    m_lbl_status_mode = new(std::nothrow) QLabel(this);
     status_bar->addWidget(m_lbl_status_mode);
     m_lbl_status_mode->setSizePolicy(policy);
     m_lbl_status_mode->setFrameStyle(frame_style);
 
-    m_lbl_status_size = new QLabel(this);
+    m_lbl_status_size = new(std::nothrow) QLabel(this);
     status_bar->addWidget(m_lbl_status_size);
     m_lbl_status_size->setSizePolicy(policy);
     m_lbl_status_size->setFrameStyle(frame_style);
@@ -571,6 +570,8 @@ QList<Kwave::FileContext *> Kwave::TopWidget::detachAllContexts()
 //***************************************************************************
 void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
 {
+    Kwave::FileContext *old_default_context = Q_NULLPTR;
+
     // if no context was given: create a new empty default context
     if (!context) {
 	context = newFileContext();
@@ -592,7 +593,8 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
 	    if (!m_context_map.isEmpty()) {
                 Kwave::FileContext *ctx = m_context_map[Q_NULLPTR];
                 m_context_map.remove(Q_NULLPTR);
-		if (ctx) ctx->release();
+		Q_ASSERT(ctx != context);
+		old_default_context = ctx;
 	    }
 	    // take over the new context
 	    m_context_map[Q_NULLPTR] = context;
@@ -696,10 +698,13 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
     // update the menu bar, toolbar etc.
     emit sigFileContextSwitched(Q_NULLPTR);
     emit sigFileContextSwitched(context);
+
     updateMenu();
     updateToolbar();
     updateCaption();
 
+    if (old_default_context)
+	old_default_context->release();
 }
 
 //***************************************************************************
@@ -724,7 +729,7 @@ int Kwave::TopWidget::executeCommand(const QString &line)
     if (false) {
     CASE_COMMAND("about_kde")
 	// Help / About KDE
-	KHelpMenu *dlg = new KHelpMenu(this, _("Kwave"));
+	KHelpMenu *dlg = new(std::nothrow) KHelpMenu(this, _("Kwave"));
 	if (dlg) dlg->aboutKDE();
 	result = 0;
     CASE_COMMAND("menu")
@@ -1082,7 +1087,7 @@ int Kwave::TopWidget::openRecent(const QString &str)
 int Kwave::TopWidget::openFile()
 {
     QString filter = Kwave::CodecManager::decodingFilter();
-    QPointer<Kwave::FileDialog> dlg = new (std::nothrow) Kwave::FileDialog(
+    QPointer<Kwave::FileDialog> dlg = new(std::nothrow) Kwave::FileDialog(
 	_("kfiledialog:///kwave_open_dir"),
 	Kwave::FileDialog::OpenFile, filter, this
     );
