@@ -17,11 +17,11 @@
 
 #include "config.h"
 
+#include <new>
+
 #include <QLatin1Char>
 #include <QPixmap>
 
-#include <KIconLoader>
-
 #include "libkwave/Parser.h"
 #include "libkwave/String.h"
 
@@ -52,7 +52,7 @@ Kwave::MenuNode::~MenuNode()
 	group = m_groups.begin();
     }
 
-    // remove all clients
+    // remove all childs
     clear();
 
     // de-register from our parent
@@ -200,11 +200,11 @@ Kwave::MenuNode *Kwave::MenuNode::findUID(const QString &uid)
     if (m_uid == uid) return this;    // found ourself
 
     foreach (Kwave::MenuNode *child, m_children) {
-	Kwave::MenuNode *node = (child) ? child->findUID(uid) : 0;
+        Kwave::MenuNode *node = (child) ? child->findUID(uid) : Q_NULLPTR;
 	if (node) return node;    // found in child
     }
 
-    return 0;    // nothing found :-(
+    return Q_NULLPTR;    // nothing found :-(
 }
 
 //*****************************************************************************
@@ -216,7 +216,7 @@ Kwave::MenuNode *Kwave::MenuNode::findChild(const QString &name)
 	if (child && (name == child->name()))
 	    return child;
     }
-    return 0;
+    return Q_NULLPTR;
 }
 
 //*****************************************************************************
@@ -236,7 +236,7 @@ Kwave::MenuSub *Kwave::MenuNode::insertBranch(const QString &name,
     Q_UNUSED(command);
     Q_UNUSED(shortcut);
     Q_UNUSED(uid);
-    return 0;
+    return Q_NULLPTR;
 }
 
 //*****************************************************************************
@@ -249,7 +249,7 @@ Kwave::MenuNode *Kwave::MenuNode::insertLeaf(const QString &name,
     Q_UNUSED(command);
     Q_UNUSED(shortcut);
     Q_UNUSED(uid);
-    return 0;
+    return Q_NULLPTR;
 }
 
 //*****************************************************************************
@@ -330,7 +330,7 @@ Kwave::MenuNode *Kwave::MenuNode::leafToBranch(Kwave::MenuNode *node)
     Q_ASSERT(node);
     Q_ASSERT(node != this);
 
-    if (!node || (node==this)) return 0;
+    if (!node || (node == this)) return Q_NULLPTR;
 
     // get the old properties
     bool old_enable           = node->isEnabled();
@@ -379,15 +379,15 @@ void Kwave::MenuNode::joinGroup(const QString &group,
                                 Kwave::MenuGroup::Mode mode)
 {
     if (m_groups.contains(group))
-	return ;    // already joined
+	return;    // already joined
 
     QHash<QString, Kwave::MenuGroup *> &group_list = groupList();
-    Kwave::MenuGroup *grp = 0;
+    Kwave::MenuGroup *grp = Q_NULLPTR;
     if (group_list.contains(group)) {
 	grp = group_list[group];
     } else {
 	// group does not already exist, create a new one
-	grp = new Kwave::MenuGroup(rootNode(), group, mode);
+        grp = new(std::nothrow) Kwave::MenuGroup(rootNode(), group, mode);
 	if (grp) group_list.insert(group, grp);
     }
 
@@ -403,7 +403,7 @@ void Kwave::MenuNode::leaveGroup(const QString &group)
 {
     QHash<QString, Kwave::MenuGroup *> &group_list = groupList();
     Kwave::MenuGroup *grp = (group_list.contains(group)) ?
-	group_list.value(group) : 0;
+	group_list.value(group) : Q_NULLPTR;
 
     // remove the group from our list
     m_groups.removeAll(group);
@@ -424,19 +424,15 @@ bool Kwave::MenuNode::specialCommand(const QString &command)
 
     if (parser.command() == _("#icon")) {
 	// --- give the item an icon ---
-	const QString &filename = parser.firstParam();
-	if (filename.length()) {
+	const QString &icon_name = parser.firstParam();
+	if ( icon_name.length()) {
 	    // try to load from standard dirs
-	    KIconLoader loader;
-	    QIcon icon = loader.loadIcon(filename,
-		KIconLoader::Small, 0, KIconLoader::DefaultState,
-		QStringList(), 0, true);
-
+	    QIcon icon = QIcon::fromTheme( icon_name );
 	    if (!icon.isNull()) {
 		setIcon(icon);
 	    } else {
 		qWarning("MenuNode '%s': icon '%s' not found !",
-		    DBG(name()), DBG(filename));
+		    DBG(name()), DBG( icon_name ));
 	    }
 	}
 	return true;
@@ -454,11 +450,12 @@ bool Kwave::MenuNode::specialCommand(const QString &command)
 	const QString uid = parser.firstParam();
 	const QString cmd = parser.nextParam();
 	if (!sub->findUID(uid)) {
-	    Kwave::MenuList *placeholder = new Kwave::MenuList(sub, cmd, uid);
+            Kwave::MenuList *placeholder =
+                new(std::nothrow) Kwave::MenuList(sub, cmd, uid);
 	    Q_ASSERT(placeholder);
 	    if (!placeholder) return false;
 
-	    sub->insertChild(placeholder, 0);
+            sub->insertChild(placeholder, Q_NULLPTR);
 	}
 	return true;
     }
