@@ -55,7 +55,7 @@ namespace Kwave
 	                 const QList<unsigned int> *tracks);
 
 	/** Destructor */
-	virtual ~SelectionTracker();
+        virtual ~SelectionTracker() Q_DECL_OVERRIDE;
 
 	/**
 	 * Returns all currently selected tracks
@@ -199,7 +199,7 @@ namespace Kwave
 	 * @retval false if saving undo data failed, e.g. out of memory
 	 *               or aborted
 	 */
-	bool saveUndoData(Kwave::UndoTransaction &undo) Q_DECL_OVERRIDE;
+        virtual bool saveUndoData(Kwave::UndoTransaction &undo) Q_DECL_OVERRIDE;
 
     private:
 
@@ -217,12 +217,12 @@ namespace Kwave
 	    explicit Undo(Kwave::SelectionTracker *selection);
 
 	    /** Destructor */
-	    virtual ~Undo();
+            virtual ~Undo() Q_DECL_OVERRIDE;
 
 	    /**
 	     * Returns a verbose short description of the action.
 	     */
-	    QString description() Q_DECL_OVERRIDE;
+            virtual QString description() Q_DECL_OVERRIDE;
 
 	    /**
 	     * Returns the required amount of memory that is needed for storing
@@ -230,13 +230,13 @@ namespace Kwave
 	     * free memory to be reserved.
 	     * @note this is the first step (after the constructor)
 	     */
-	    qint64 undoSize() Q_DECL_OVERRIDE;
+            virtual qint64 undoSize() Q_DECL_OVERRIDE;
 
 	    /**
 	     * Returns the difference of needed memory that is needed for
 	     * redo.
 	     */
-	    qint64 redoSize() Q_DECL_OVERRIDE;
+            virtual qint64 redoSize() Q_DECL_OVERRIDE;
 
 	    /**
 	     * Stores the data needed for undo.
@@ -244,7 +244,7 @@ namespace Kwave
 	     * @note this is the second step, after size() has been called
 	     * @return true if successful, false if failed (e.g. out of memory)
 	     */
-	    bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
+            virtual bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
 
 	    /**
 	     * Takes back an action by creating a new undo action (for further
@@ -256,7 +256,7 @@ namespace Kwave
 	     *       undo/redo. You have to check for this when deleting an
 	     *       UndoAction object after undo.
 	     */
-	    Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+            virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
 	                                    bool with_redo) Q_DECL_OVERRIDE;
 
 	    /**
@@ -264,10 +264,12 @@ namespace Kwave
 	     * of the signal.
 	     * @return true always
 	     */
-	    bool containsModification() const Q_DECL_OVERRIDE { return false; }
+            virtual bool containsModification() const Q_DECL_OVERRIDE {
+                return false;
+            }
 
 	    /** dump, for debugging purposes */
-	    void dump(const QString &indent) Q_DECL_OVERRIDE {
+            virtual void dump(const QString &indent) Q_DECL_OVERRIDE {
 		qDebug("%s%s", DBG(indent), DBG(description()));
 	    }
 
