@@ -88,7 +88,7 @@ namespace Kwave
 	/**
 	 * Destructor.
 	 */
-	virtual ~Plugin();
+        virtual ~Plugin() Q_DECL_OVERRIDE;
 
 	/** Returns the name of the plugin. */
 	virtual QString name() const;
@@ -228,8 +228,9 @@ namespace Kwave
 	 * @return the number of selected samples (right-left+1) [1..length]
 	 */
 	virtual sample_index_t selection(
-	    QList<unsigned int> *tracks = 0,
-	    sample_index_t *left = 0, sample_index_t *right=0,
+            QList<unsigned int> *tracks = Q_NULLPTR,
+            sample_index_t *left = Q_NULLPTR,
+            sample_index_t *right = Q_NULLPTR,
 	    bool expand_if_empty = false);
 
 	/**
@@ -338,7 +339,7 @@ namespace Kwave
 	friend class Kwave::WorkerThread;
 
 	/** Wrapper for run() that contains a call to release() */
-	void run_wrapper(const QVariant &params) Q_DECL_OVERRIDE;
+        virtual void run_wrapper(const QVariant &params) Q_DECL_OVERRIDE;
 
     private:
 
