@@ -17,6 +17,9 @@
 
 #include "config.h"
 
+#include <limits>
+#include <new>
+
 #include <QtGlobal>
 #include <QByteArray>
 #include <QMetaObject>
@@ -57,7 +60,8 @@ bool Kwave::ChannelMixer::init()
     // create the buffers for the output data
     for (unsigned int index = 0; index < m_outputs; ++index) {
 	// create a buffer for the input
-	Kwave::SampleBuffer *out_buffer = new Kwave::SampleBuffer();
+	Kwave::SampleBuffer *out_buffer =
+	    new(std::nothrow) Kwave::SampleBuffer();
 	Q_ASSERT(out_buffer);
 	if (!out_buffer) return false;
 	m_output_buffer.append(out_buffer);
@@ -65,7 +69,8 @@ bool Kwave::ChannelMixer::init()
 
     // create indexing proxies and connect their output to this mixer
     for (unsigned int index = 0; index < m_inputs; ++index) {
-	Kwave::StreamObject *indexer = new Kwave::Indexer(index);
+	Kwave::StreamObject *indexer =
+	    new(std::nothrow) Kwave::Indexer(index);
 	Q_ASSERT(indexer);
 	if (!indexer) return false;
 
@@ -80,7 +85,7 @@ bool Kwave::ChannelMixer::init()
     // create the mixer matrix
     // create a translation matrix for mixing up/down to the desired
     // number of output channels
-    m_matrix = new Kwave::MixerMatrix(m_inputs, m_outputs);
+    m_matrix = new(std::nothrow) Kwave::MixerMatrix(m_inputs, m_outputs);
     Q_ASSERT(m_matrix);
     if (!m_matrix) return false;
 
@@ -196,7 +201,7 @@ void Kwave::ChannelMixer::mix()
     // and form an array of pointers to the raw data, for speeding up
     QVector<Kwave::SampleArray> v_input(m_inputs);
     QVarLengthArray<const sample_t *> input(m_inputs);
-    unsigned int min_len = UINT_MAX;
+    unsigned int min_len = std::numeric_limits<unsigned int>::max();
     for (unsigned int track = 0; track < m_inputs; track++) {
 	// dequeue the buffer with input data
 	QQueue<Kwave::SampleArray> &queue = m_input_queue[track];
