@@ -21,6 +21,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <new>
+
 #include <id3/globals.h>
 #include <id3/misc_support.h>
 #include <id3/tag.h>
@@ -71,7 +73,7 @@ Kwave::MP3Decoder::~MP3Decoder()
 //***************************************************************************
 Kwave::Decoder *Kwave::MP3Decoder::instance()
 {
-    return new MP3Decoder();
+    return new(std::nothrow) MP3Decoder();
 }
 
 //***************************************************************************
@@ -191,16 +193,13 @@ bool Kwave::MP3Decoder::parseMp3Header(const Mp3_Headerinfo &header,
     if (header.emphasis > 0)
         info.set(Kwave::INF_MPEG_EMPHASIS, header.emphasis);
 
-//  qDebug("framesize=%d", header.framesize);
-//  qDebug("frames = %u", header.frames);
-
     if (header.privatebit)  info.set(Kwave::INF_PRIVATE, header.privatebit);
     if (header.copyrighted) info.set(Kwave::INF_COPYRIGHTED, header.copyrighted);
     if (header.original)    info.set(Kwave::INF_ORIGINAL, header.original);
 
     info.setRate(header.frequency); // sample rate
     info.setBits(SAMPLE_BITS);      // fake Kwave's default resolution
-    info.setLength(header.time * header.frequency);
+    info.set(INF_ESTIMATED_LENGTH, header.time * header.frequency);
 
     metaData().replace(Kwave::MetaDataList(info));
 
