@@ -39,14 +39,15 @@ namespace Kwave
 	NewSignalPlugin(QObject *parent, const QVariantList &args);
 
 	/** virtual Destructor */
-	virtual ~NewSignalPlugin();
+        virtual ~NewSignalPlugin() Q_DECL_OVERRIDE;
 
 	/**
 	 * Shows a dialog for creating a new signal and emits sigCommand if
 	 * OK has been pressed.
 	 * @see Kwave::Plugin::setup
 	 */
-	QStringList *setup(QStringList &previous_params) Q_DECL_OVERRIDE;
+        virtual QStringList *setup(QStringList &previous_params)
+            Q_DECL_OVERRIDE;
 
     protected:
 
