@@ -111,8 +111,7 @@ void Kwave::NormalizePlugin::run(QStringList params)
 	    Qt::BlockingQueuedConnection);
 
     // connect them
-    bool ok = true;
-    if (ok) ok = Kwave::connect(
+    bool ok = Kwave::connect(
 	source,     SIGNAL(output(Kwave::SampleArray)),
 	normalizer, SLOT(input(Kwave::SampleArray)));
     if (ok) ok = Kwave::connect(
