@@ -54,33 +54,33 @@ namespace Kwave
 	PlayBackQt();
 
 	/** Destructor */
-	virtual ~PlayBackQt();
+        virtual ~PlayBackQt() Q_DECL_OVERRIDE;
 
 	/**
 	 * Opens the device for playback.
 	 * @see PlayBackDevice::open
 	 */
-	QString open(const QString &device, double rate,
-	             unsigned int channels, unsigned int bits,
-	             unsigned int bufbase) Q_DECL_OVERRIDE;
+        virtual QString open(const QString &device, double rate,
+	                     unsigned int channels, unsigned int bits,
+	                     unsigned int bufbase) Q_DECL_OVERRIDE;
 
 	/**
 	 * Writes an array of samples to the output device.
 	 * @see PlayBackDevice::write
 	 */
-	int write(const Kwave::SampleArray &samples) Q_DECL_OVERRIDE;
+        virtual int write(const Kwave::SampleArray &samples) Q_DECL_OVERRIDE;
 
 	/**
 	 * Closes the output device.
 	 * @see PlayBackDevice::close
 	 */
-	int close() Q_DECL_OVERRIDE;
+        virtual int close() Q_DECL_OVERRIDE;
 
 	/** return a string list with supported device names */
-	QStringList supportedDevices() Q_DECL_OVERRIDE;
+        virtual QStringList supportedDevices() Q_DECL_OVERRIDE;
 
 	/** return a string suitable for a "File Open..." dialog */
-	QString fileFilter() Q_DECL_OVERRIDE;
+        virtual QString fileFilter() Q_DECL_OVERRIDE;
 
 	/**
 	 * returns a list of supported bits per sample resolutions
@@ -89,7 +89,7 @@ namespace Kwave
 	 * @param device filename of the device
 	 * @return list of supported bits per sample, or empty on errors
 	 */
-	QList<unsigned int> supportedBits(const QString &device)
+        virtual QList<unsigned int> supportedBits(const QString &device)
             Q_DECL_OVERRIDE;
 
 	/**
@@ -101,8 +101,8 @@ namespace Kwave
 	 * @param max receives the highest supported number of channels
 	 * @return zero or positive number if ok, negative error number if failed
 	 */
-	int detectChannels(const QString &device,
-	                   unsigned int &min, unsigned int &max)
+        virtual int detectChannels(const QString &device,
+	                           unsigned int &min, unsigned int &max)
             Q_DECL_OVERRIDE;
 
     private slots:
@@ -144,7 +144,7 @@ namespace Kwave
 	    Buffer();
 
 	    /** destructor */
-	    virtual ~Buffer();
+            virtual ~Buffer() Q_DECL_OVERRIDE;
 
 	    /**
 	     * start filling the buffer
@@ -177,7 +177,7 @@ namespace Kwave
 	     * @param len number of bytes to read
 	     * @return number of bytes that have been read
 	     */
-	    qint64 readData(char *data, qint64 len) Q_DECL_OVERRIDE;
+            virtual qint64 readData(char *data, qint64 len) Q_DECL_OVERRIDE;
 
 	    /**
 	     * write data into the buffer, called from our own worker thread
@@ -185,10 +185,11 @@ namespace Kwave
 	     * @param len number of bytes to write
 	     * @return number of bytes written
 	     */
-	    qint64 writeData(const char *data, qint64 len) Q_DECL_OVERRIDE;
+            virtual qint64 writeData(const char *data, qint64 len)
+                Q_DECL_OVERRIDE;
 
 	    /** returns the number of bytes available for reading */
-	    qint64 bytesAvailable() const Q_DECL_OVERRIDE;
+            virtual qint64 bytesAvailable() const Q_DECL_OVERRIDE;
 
 	private:
 
