@@ -24,7 +24,7 @@
 #include <sys/ioctl.h>
 #include <sys/soundcard.h>
 #include <sys/stat.h>
-#include <sys/types.h>
+#include <stdlib.h>
 #include <unistd.h>
 
 #include <QDir>
@@ -208,7 +208,7 @@ int Kwave::RecordOSS::read(QByteArray &buffer, unsigned int offset)
 	    length -= res;
 	    buf += res;
 	} else {
-	    printf("No data within 5 seconds.\n");
+	    qWarning("No data within 5 seconds.\n");
 	    return -EIO;
         }
     }
