@@ -35,6 +35,8 @@
 #include "libkwave/Writer.h"
 #include "libkwave/modules/RateConverter.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
+#include "libkwave/undo/UndoAddMetaDataAction.h"
+#include "libkwave/undo/UndoDeleteMetaDataAction.h"
 
 #include "SampleRatePlugin.h"
 
@@ -68,7 +70,6 @@ int Kwave::SampleRatePlugin::interpreteParameters(QStringList &params)
 
     param = params[0];
     m_new_rate = param.toDouble(&ok);
-    Q_ASSERT(ok);
     if (!ok) return -EINVAL;
 
     // check whether we should change the whole signal (optional)
@@ -116,6 +117,7 @@ void Kwave::SampleRatePlugin::run(QStringList params)
 	    m_whole_signal = true;
 	}
     }
+
     qDebug("SampleRatePlugin: from %9lu - %9lu (%9lu)",
 	   static_cast<unsigned long int>(first),
 	   static_cast<unsigned long int>(last),
@@ -127,6 +129,17 @@ void Kwave::SampleRatePlugin::run(QStringList params)
     sample_index_t new_length = static_cast<sample_index_t>(length * ratio);
     if ((new_length == length) || !new_length) return;
 
+    Kwave::MetaDataList meta = mgr.metaData().selectByRange(first, last);
+    if (!meta.isEmpty()) {
+	// delete the meta data from the original range
+	Kwave::UndoDeleteMetaDataAction *undo_del_meta = new(std::nothrow)
+	    Kwave::UndoDeleteMetaDataAction(meta);
+	if (!undo_guard.registerUndoAction(undo_del_meta))
+	    return;
+
+	mgr.metaData().deleteRange(first, last);
+    }
+
     // if the new length is bigger than the current length,
     // insert some space at the end
     if (new_length > length) {
@@ -158,8 +171,7 @@ void Kwave::SampleRatePlugin::run(QStringList params)
 	first, first + new_length - 1);
 
     // connect the objects
-    bool ok = true;
-    if (ok) ok = Kwave::connect(
+    bool ok = Kwave::connect(
 	source,    SIGNAL(output(Kwave::SampleArray)),
 	converter, SLOT(input(Kwave::SampleArray)));
     if (ok) ok = Kwave::connect(
@@ -186,39 +198,21 @@ void Kwave::SampleRatePlugin::run(QStringList params)
     }
 
     // adjust meta data locations
-    Kwave::MetaDataList meta = mgr.metaData().copy(first, last, tracks);
     if (!meta.isEmpty()) {
-	// adjust all positions in the originally selected range
-	// NOTE: if the ratio is > 1, work backwards, otherwise forward
+	// adjust all meta data positions
+	meta.shiftLeft(first, first);
+	meta.scalePositions(ratio);
+	meta.shiftRight(0, first);
 
-	Kwave::MetaDataList::MutableIterator it(meta);
-	(ratio > 1) ? it.toBack() : it.toFront();
-	while ((ratio > 1) ? it.hasPrevious() : it.hasNext()) {
-	    Kwave::MetaData &m = (ratio > 1) ?
-		it.previous().value() : it.next().value();
-
-	    QStringList properties =
-	        Kwave::MetaData::positionBoundPropertyNames();
-	    foreach (const QString &property, properties) {
-		if (!m.hasProperty(property))
-		    continue;
-
-		sample_index_t pos = static_cast<sample_index_t>(
-		    m[property].toULongLong());
-		if (pos < first) continue;
-		if (pos > last)  continue;
-
-		// is in our range -> calculate new position
-		pos -= first;
-		pos *= ratio;
-		pos += first;
-
-		m[property] = pos;
-	    }
+	Kwave::UndoAddMetaDataAction *undo_add_meta = new(std::nothrow)
+	    Kwave::UndoAddMetaDataAction(meta);
+	if (!undo_guard.registerUndoAction(undo_add_meta)) {
+	    undo_guard.abort();
+	    return;
 	}
 
-	mgr.metaData().deleteRange(first, last, tracks);
-	mgr.metaData().merge(meta);
+	// add the updated meta data items again
+	mgr.metaData().add(meta);
     }
 
     // update the selection if it was not empty
